<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet 
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

  <!-- Append new flagged messages to Audit Window and modify timer callback argument
       ==============================================================================
  -->

  <xsl:import href='gjsTree.xsl' />
  <xsl:include href='ServerLink.xsl' />

  <!-- templates divMainHead, folderContents and leafContent are in here -->
  <xsl:include href='AuditTrail_Row.xsl' />

	<!-- Item caption -->
  <xsl:variable name='g_capItem'>
    <xsl:call-template name='gjs:i18n'>
      <xsl:with-param name='string' select='"Item"'/>
    </xsl:call-template>
  </xsl:variable>

  <!-- Process each row -->
  <xsl:template match="/ServerLink/Rows">

    <!-- Process errors, if any -->
    <xsl:if test='/ServerLink/Rows/error'>
      <div id='divError'>
        <script id='xErrors' type='application/xml'>
          <errors>
            <xsl:apply-templates select='/ServerLink/Rows/error' mode='dataset'/>
          </errors>
        </script>
        <xsl:if test='/ServerLink/alertErrors/@alertErrors="1"'>
          <script>
          <xsl:apply-templates select='/ServerLink/Rows/error' mode='alert'/>
          </script>
        </xsl:if>
      </div>
    </xsl:if>

    <!-- If there are any messages with popup set then generate alert scripts
         These could either be persistent messages (look in audit/category) or transient messages (look in category) -->
    <xsl:apply-templates select='/ServerLink/Rows/*[audit/category/@popupMessage="yes" or category/@popupMessage="yes"]' mode='popup' />

    <!-- Process the leaves (if there are any) -->
    <xsl:if test='/ServerLink/Rows[Leaf or Folder]'>
      <xsl:call-template name='gjs:tree'/>
    </xsl:if>
  
    <!-- Start a timer that will look for new flagged messages when it expires -->
    <script>
      parent.frameMain.AuditTrail.fnSetTimer("<xsl:value-of select='/ServerLink/Rows/Folder[last()]/audit/@atline'/>")
    </script>

  </xsl:template>


  <!-- We don't need to send column headings as we are just appending to an existing table
       which should already have column headings -->
  <xsl:template name='divMainHead'>
  </xsl:template>
  

  <!-- Process error message elements, in two phases (using modes):
    a) Add message element to XML dataset
    b) Add alert() call -->
  <xsl:template match='/ServerLink/Rows/error' mode='dataset'>
    <xsl:variable name='message'>
      <xsl:call-template name='gjs:i18n-parameterized'>
        <xsl:with-param name='message' select='.'/>
      </xsl:call-template>
    </xsl:variable>
    <message message='{$message}' severity='{@severity}'/>
  </xsl:template>
  
  <xsl:template match='/ServerLink/Rows/error' mode='alert'>
    <xsl:variable name='message'>
      <xsl:call-template name='gjs:i18n-parameterized'>
        <xsl:with-param name='message' select='.'/>
      </xsl:call-template>
    </xsl:variable>
      <xsl:text>alert('</xsl:text>
      <xsl:call-template name='escape-javascript'>
        <xsl:with-param name='string' select='$message' />
      </xsl:call-template>
      <xsl:text>')</xsl:text>
  </xsl:template>


  <!-- Generate popup message if appropriate -->
  <xsl:template match='/ServerLink/Rows/*/message' mode='popup'>
    <xsl:variable name='message'>
      <xsl:call-template name='gjs:i18n-parameterized'>
        <xsl:with-param name='message' select='.'/>
      </xsl:call-template>
    </xsl:variable>

    <script>
      <xsl:text>alert('</xsl:text>
      <xsl:call-template name='escape-javascript'>
        <xsl:with-param name='string' select='concat($g_capItem,": ",@item)' />
      </xsl:call-template>
      <xsl:text>\n</xsl:text>
      <xsl:call-template name='escape-javascript'>
        <xsl:with-param name='string' select='$message' />
      </xsl:call-template>
      <xsl:text>')</xsl:text>
    </script>
  </xsl:template>
  
  <!-- Attributes for each folder row -->
  <xsl:template name='folderRowAttributes'>
    <xsl:call-template name='leafRowAttributes'/>
  </xsl:template>

  <!-- Attributes for each leaf row -->
  <xsl:template name='leafRowAttributes'>

    <xsl:variable name='onfocus'>
      <xsl:if test='audit'>
        <xsl:text>fnItemSelect(this);</xsl:text>
        <xsl:text>Class.fnSelect(AuditTrail,this);</xsl:text>
        <xsl:text>Main.fnSetMainHead("divMessagesReferenceHeading");</xsl:text>
      </xsl:if>
    </xsl:variable>

    <!-- Get colour, use the audit trail's category, or the message's category -->
    <xsl:variable name='color'>
      <xsl:choose>
        <xsl:when test='audit'>
          <xsl:value-of select='audit/category/@color' />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select='category/@color' />
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>

    <xsl:attribute name='tabindex'>0</xsl:attribute>
    <xsl:attribute name='onfocus'><xsl:value-of select='$onfocus' /></xsl:attribute>
    <xsl:attribute name='onclick'><xsl:value-of select='$onfocus' /></xsl:attribute>
    <xsl:attribute name='ondblclick'>
      <xsl:if test='audit'>AuditTrail.Item.fnOpen()</xsl:if>
    </xsl:attribute>
    <xsl:attribute name='gjsItem'><xsl:value-of select='audit/@item' /></xsl:attribute>
    <xsl:attribute name='gjsAtLine'><xsl:value-of select='audit/@atline' /></xsl:attribute>
    <xsl:attribute name='style'>color: <xsl:value-of select='$color' /></xsl:attribute>
  </xsl:template>

  <!-- Escape single-quotes and convert $c(10) to \n-->
  <xsl:template name='escape-javascript'>
    <xsl:param name='string' />
    <xsl:choose>
      <xsl:when test='contains($string, "&apos;")'>
        <xsl:call-template name='escape-javascript'>
          <xsl:with-param name='string'
            select='substring-before($string, "&apos;")' />
        </xsl:call-template>
        <xsl:text>\'</xsl:text>
        <xsl:call-template name='escape-javascript'>
          <xsl:with-param name='string'
            select='substring-after($string, "&apos;")' />
        </xsl:call-template>
      </xsl:when>
      <xsl:when test='contains($string, "&#xA;")'>
        <xsl:call-template name='escape-javascript'>
          <xsl:with-param name='string'
            select='substring-before($string, "&#xA;")' />
        </xsl:call-template>
        <xsl:text>\n</xsl:text>
        <xsl:call-template name='escape-javascript'>
          <xsl:with-param name='string'
            select='substring-after($string, "&#xA;")' />
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise><xsl:value-of select='$string' /></xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
