@echo off
rem Copyright 2004 George James Software Limited

rem This command file converts the vcmConfiguration.xml file into a partial cache.cpf file
rem named vcCache.cpf.  It creates the database, namespace and mapping segments of a cpf file.
rem
rem You will need to copy vcmCpfParameters.xml.template to vcmCpfParameters.xml and customize it
rem to be suitable for your particular environment and cpf file.
rem
rem You must have java 1.4 or later installed in order to be able to run these commands.
rem Xalan is installed as part of java, so there are no additional installation steps.

rem Check that parameter file has been created
if not exist vcmCpfParameters.xml goto noVcmCpfParameters

if exist vcmConfigurationPass1.xml del vcmConfigurationPass1.xml
if exist vcmConfigurationPass2.xml del vcmConfigurationPass2.xml
if exist vcmConfigurationCacheCpf.xml del vcmConfigurationCacheCpf.xml
if exist vcmCache.cpf del vcmCache.cpf

echo Processing vcmConfiguration.xml...
java org.apache.xalan.xslt.Process -in vcmConfiguration.xml -xsl vcmConfiguration.xml#xsl -out vcmConfigurationPass1.xml
if not errorlevel 0 goto error
echo vcmConfigurationPass1.xml created.

echo Processing vcmConfigurationPass1.xml...
java org.apache.xalan.xslt.Process -in vcmConfigurationPass1.xml -xsl vcmConfiguration.xml#xsl -out vcmConfigurationPass2.xml
if not errorlevel 0 goto error
echo vcmConfigurationPass2.xml created.
   
echo Creating vcmConfigurationCacheCpf.xml...
java org.apache.xalan.xslt.Process -in vcmConfigurationPass2.xml -xsl vcmConfigurationXmlToCacheCpfXml.xsl -out vcmConfigurationCacheCpf.xml
if not errorlevel 0 goto error
echo vcmConfigurationCacheCpf.xml created.

echo Creating vcmCache.Cpf...
java org.apache.xalan.xslt.Process -in vcmConfigurationCacheCpf.xml -xsl cacheCpf.xsl -out vcmCache.cpf
if not errorlevel 0 goto error
echo vcmCache.cpf created.


echo Done.
goto done

:noVcmCpfParameters
echo Error: The file vcmCpfParameters.xml does not exist.
echo        You must create this file by copying vcmCpfParameters.xml.template
echo        and then customizing the parameter values within it to suit your
echo        environment.
echo Aborted.
goto done

:error
echo Aborted.

:done
pause
