<?xml version='1.0' encoding='UTF-8'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet 
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

<!-- Object List
     ===========
-->

<xsl:import href='gjsTree.xsl' />
<xsl:include href='ServerLink.xsl' />


<xsl:template match="/ServerLink/Rows">

  <xsl:if test='/ServerLink/Rows/@mores=""'>
    <div id='divFolderHeadingCaption'>
      <xsl:choose>
        <xsl:when test='not(/ServerLink/location/@location="")'>
          Objects at <xsl:value-of select='/ServerLink/location/@location' />
        </xsl:when>
        <xsl:when test='not(/ServerLink/system/@system="")'>
          Objects in System <xsl:value-of select='/ServerLink/system/@system' />
        </xsl:when>
        <xsl:otherwise>
          All Objects
        </xsl:otherwise>
      </xsl:choose>
    </div>
  </xsl:if>

  <div id='divMainHead'>
    <xsl:call-template name='divMainHead' />
  </div>

  <xsl:call-template name='gjs:tree'/>

</xsl:template>


<!-- Attach handler to table -->
<xsl:template name='tableAttributes'>
  <xsl:param name='tableId'/>
  <xsl:attribute name='onkeydown'>fnTreeTableKeyDown(Object,this,event);</xsl:attribute>
</xsl:template>


<!-- Column headings for main panel, including 2000px blank trailing one to allow real last one to be resized -->
<xsl:template name='divMainHead'>

  	<table class='layoutTable' width='1000px' gjsTreeId='Object_List'>
  	  <tr>

        <xsl:call-template name='gjs:treeMoresMainHeading' />

	<td width='25px'></td>

        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"200"'/> 
          <xsl:with-param name='caption'>Object</xsl:with-param>
          <xsl:with-param name='columnId'>Object</xsl:with-param>
          <xsl:with-param name='selected'>ascending</xsl:with-param>
	        <xsl:with-param name='previousColumnResizable'>0</xsl:with-param>
        </xsl:call-template>

        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"100"'/> 
	        <xsl:with-param name='columnId'>Master</xsl:with-param>
          <xsl:with-param name='caption'>Master</xsl:with-param>        
          <xsl:with-param name='title'>Location holding master copy of object</xsl:with-param>
        </xsl:call-template>

        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"350"'/> 
	        <xsl:with-param name='columnId'>Description</xsl:with-param>
          <xsl:with-param name='caption'>Description</xsl:with-param>   
        </xsl:call-template>
        
        <xsl:choose>
          <xsl:when test='not(/ServerLink/location/@location="")'>
            <xsl:call-template name='gjs:treeColumnHeading'>
              <xsl:with-param name='width' select='"100"'/> 
              <xsl:with-param name='columnId'>DateTime</xsl:with-param>
              <xsl:with-param name='caption'>Date</xsl:with-param>
              <xsl:with-param name='title'>Date and time of most recent activation at this location</xsl:with-param>
            </xsl:call-template>
  
            <xsl:call-template name='gjs:treeColumnHeading'>
              <xsl:with-param name='width' select='"60"'/> 
              <xsl:with-param name='columnId'>User</xsl:with-param>
              <xsl:with-param name='caption'>By</xsl:with-param>        
              <xsl:with-param name='title'>User who activated object at this location most recently</xsl:with-param>
            </xsl:call-template>
          </xsl:when>
          
          <xsl:otherwise>
            <xsl:call-template name='gjs:treeColumnHeading'>
              <xsl:with-param name='width' select='"100"'/> 
              <xsl:with-param name='columnId'>DateTime</xsl:with-param>
              <xsl:with-param name='caption'>Date</xsl:with-param>
              <xsl:with-param name='title'>Date this object was created</xsl:with-param>
            </xsl:call-template>
  
            <xsl:call-template name='gjs:treeColumnHeading'>
              <xsl:with-param name='width' select='"60"'/> 
              <xsl:with-param name='columnId'>User</xsl:with-param>
              <xsl:with-param name='caption'>By</xsl:with-param>        
              <xsl:with-param name='title'>User who created this object</xsl:with-param>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>
        
        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"2000"'/> 
        </xsl:call-template>

        <td width='*'></td>

      </tr>
    </table>

</xsl:template>


<xsl:template name='folderContent'>
  <xsl:param name='rowId'/>

  <xsl:apply-templates select='ChangeRequest'>
    <xsl:with-param name='rowId' select='$rowId' />  
  </xsl:apply-templates>

  <xsl:apply-templates select='objectVersion'>
    <xsl:with-param name='rowId' select='$rowId' />
  </xsl:apply-templates>

  <xsl:apply-templates select='Transaction'>
    <xsl:with-param name='rowId' select='$rowId' />  
  </xsl:apply-templates>

</xsl:template>
  

<!-- When objects are listed within a change request, the first row is a folder containing
     audit trail entries for the change request -->
<xsl:template match='/ServerLink/Rows/HeadFolder/ChangeRequest'>
	<xsl:param name='rowId'/>
	
  <!-- Icon for Folder -->
  <td>
    <img
      src='vcm_record_l.gif'
      title='Audit trail of activity for this change request'
      width='25px'
      height='16px'/>
  </td>

  <!-- caption cell -->
  <td class='treeCell'>
  
   <div nowrap='nowrap'>
    <span tabindex='0'
     id='{$rowId}sub'
     gjsItem='{@changeRequest}'>
      Audit Trail
    </span>
   </div>
  </td>

  <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>   
  </td>

  <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

 <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

  <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

 <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

</xsl:template>
  

<!-- When an object is listed within an audit record, there may be a FootFolder for browsing the transaction -->
<xsl:template match='/ServerLink/Rows/FootFolder/Transaction'>
	<xsl:param name='rowId'/>
	
  <!-- Icon for Folder -->
  <td style='width: 25px; min-width: 25px; max-width: 25px;'>
    <img
      src='vcm_record_l.gif'
      title='All audit records for the same transaction'
      width='25px'
      height='16px'/>
  </td>

  <!-- caption cell -->
  <td class='treeCell'>
  
   <div nowrap='nowrap'>
    <span tabindex='0'
     id='{$rowId}sub'
     title='All audit records for the same transaction'
     gjsItem='{@transaction}'>
      Transaction <xsl:value-of select='@transaction'/>
    </span>
   </div>
  </td>

  <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>   
  </td>

  <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

 <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

  <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

 <td class='treeCell'>
   <div nowrap='nowrap'>
   </div>
  </td>

</xsl:template>


<xsl:template match='/ServerLink/Rows/Folder/objectVersion'>
  <xsl:param name='rowId'/>

  <xsl:variable name='info'>
    <xsl:call-template name='info'/>
  </xsl:variable>

	<xsl:variable name='elementMain'>
		fnElement("<xsl:value-of select='$rowId'/>main")
	</xsl:variable>

	<xsl:variable name='elementSub'>
		fnElement("<xsl:value-of select='$rowId'/>sub")
	</xsl:variable>


  <!-- If this is an update then use the old divReferenceHeadingId otherwise use a new unique one -->
  <xsl:variable name='divReferenceHeadingId'>
    <xsl:choose>
      <xsl:when test='../rowUpdate'>
        <xsl:value-of select='../rowUpdate/@divReferenceHeadingId' />
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select='/ServerLink/@runId' />
        <xsl:text>_mainHead</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:variable>

  <xsl:variable name='onMouseDown'>
		<xsl:text>Object.fnMouseDown(this)</xsl:text>
  </xsl:variable>

  <xsl:variable name='onMouseUp'>
		<xsl:text>Object.fnMouseUp(this)</xsl:text>
  </xsl:variable>

  <!-- Format object version so that it sorts correctly -->
  <xsl:variable name='sortableObjectVersion'>
    <xsl:value-of select='@object'/>
    <xsl:text>/</xsl:text>
    <xsl:value-of select='@variant'/>
    <xsl:text>.</xsl:text>
    <xsl:value-of select='substring(concat("00000",@version),string-length(@version))' />
  </xsl:variable>
  

  <!-- Icon for Object -->
  <td>
    <img
     onmousemove='fnItemMouseMove(Object,{$elementMain},event)'
     oncontextmenu='fnContextMenu("popObject")'
     ondragstart='window.event.returnValue=false'
		 onmousedown='fnItemMouseDown(Object,{$elementMain},event)'
		 onmouseup='fnItemMouseUp(Object,{$elementMain},event)'
     src='{../@icon}'
     title='{../@iconTitle}'
     width='25px'
     height='16px'>
			<xsl:if test='/ServerLink/allowedMethods/method[@name="Object.fnOpen"]'>
				<xsl:attribute name='ondblclick'>Object.fnOpen(getAttr(<xsl:value-of select='$elementMain'/>,"gjsItem"))</xsl:attribute>
			</xsl:if>
		</img>
  </td>

  <!-- object cell -->
  <td class='treeCell'
   gjsSort='{$sortableObjectVersion}'
   nowrap='nowrap'>
		<span
		 nowrap='nowrap'
		 id='{$rowId}main'
		 tabindex='0'
		 onmousemove='fnItemMouseMove(Object,this,event)'
		 oncontextmenu='fnContextMenu("popObject")'
		 onmousedown='fnItemMouseDown(Object,this,event)'
		 onmouseup='fnItemMouseUp(Object,this,event)'
		 title='{$info}'
		 gjsReferenceHeadingId='{$divReferenceHeadingId}'
		 gjsRowId='{$rowId}'
		 gjsIconId='{$rowId}icon'
		 gjsOnSpace='fnItemSpace(Object,event.target,event)'
		 gjsItemType='OBJECT'
		 gjsItem='{@objectVersion}'
		 gjsLocation='{/ServerLink/location/@location}'
		 gjsParentId='{/ServerLink/Rows/@parentId}'
		 gjsPtext='{@ptext}'>
			<xsl:if test='/ServerLink/allowedMethods/method[@name="Object.fnOpen"]'>
				<xsl:attribute name='ondblclick'>Object.fnOpen(getAttr(this,"gjsItem"))</xsl:attribute>
			</xsl:if>
		  <xsl:value-of select='@objectVersion'/>
		</span>
  </td>

  <!-- Master location code -->
  <td
   nowrap='nowrap'
   class='treeCell'>
    <div nowrap='nowrap'>
      <xsl:value-of select='@masterLocation'/>
    </div>
  </td>

  <!-- object description -->
  <td
   nowrap='nowrap'
   class='treeCell'>
    <div nowrap='nowrap'>
      <xsl:value-of select='@description'/>
    </div>
  </td>
  <xsl:choose>
    <xsl:when test='not(/ServerLink/location/@location="")'>
  
      <!-- datestamp at location -->
      <td
       nowrap='nowrap'
       gjsSort='{obvStatusAtLocation/@iStatusDateTime}'
       class='treeCell'>
        <div nowrap='nowrap'>
          <xsl:value-of select='obvStatusAtLocation/@statusDateTime'/>
        </div>
      </td>
  
      <!-- user at location -->
      <td
       nowrap='nowrap'
       class='treeCell'>
        <div nowrap='nowrap'>
          <xsl:value-of select='obvStatusAtLocation/@statusUserId'/>
        </div>
      </td>
    </xsl:when>
    <xsl:otherwise>
  
      <!-- datestamp of creation -->
      <td
       nowrap='nowrap'
       gjsSort='{@creationDate}'
       class='treeCell'>
        <div nowrap='nowrap'>
          <xsl:value-of select='@xCreationDate'/>
        </div>
      </td>
  
      <!-- user who created -->
      <td
       nowrap='nowrap'
       class='treeCell'>
        <div nowrap='nowrap'>
          <xsl:value-of select='@creationUserId'/>
        </div>
      </td>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- Tool tip -->
<xsl:template name='info'>
  <xsl:if test="count(objectVersionSuccessors/objectVersion)=1">
		<xsl:text>Successor version is:</xsl:text>
		<xsl:apply-templates select='objectVersionSuccessors/objectVersion' />
  </xsl:if>
  <xsl:if test="count(objectVersionSuccessors/objectVersion)>1">
		<xsl:text>Successor versions are:</xsl:text>
		<xsl:apply-templates select='objectVersionSuccessors/objectVersion' />
  </xsl:if>
</xsl:template>

<!-- List successor versions -->
<xsl:template match='/ServerLink/Rows/Folder/objectVersion/objectVersionSuccessors/objectVersion'>
  <xsl:text>&#10;&nbsp;</xsl:text>
  <xsl:value-of select='@objectVersion'/> in <xsl:value-of select='@masterLocation'/>
</xsl:template>

<!-- Sub-folder method -->
<xsl:template name='subFolderMethod'>
  <xsl:choose>
    <xsl:when test='objectVersion'>
      <xsl:text>Object.fnListSub1</xsl:text>
    </xsl:when>
    <xsl:when test='Transaction'>
      <xsl:text>AuditTrail.fnTransaction</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>ChangeRequest.fnListAuditTrail</xsl:text>
    </xsl:otherwise>
  </xsl:choose>  
</xsl:template>


<!-- Sub-folder arguments -->
<xsl:template name='subFolderArguments'>
  <xsl:param name='rowId'/>
  
	<xsl:variable name='elementMain'>
		fnElement("<xsl:value-of select='$rowId'/>main")
	</xsl:variable>

	<xsl:variable name='elementSub'>
		fnElement("<xsl:value-of select='$rowId'/>sub")
	</xsl:variable>

  <xsl:choose>
    <xsl:when test='objectVersion'>
      <xsl:text>"</xsl:text>
      <xsl:value-of select='$rowId'/>
      <xsl:text>main"+delimiter+"</xsl:text>
      <xsl:if test="objectVersion/obvStatusAtLocation">
        <xsl:value-of select='/ServerLink/location/@location'/>
      </xsl:if>
      <xsl:text>"+delimiter+getAttr(</xsl:text>
      <xsl:value-of select='$elementMain'/>
      <xsl:text>,"gjsItem")+delimiter+gjsTree.fnMores(gCurrentCell)</xsl:text>
    </xsl:when>
    <xsl:when test='Transaction'>
      <xsl:text>"</xsl:text>
      <xsl:value-of select='$rowId'/>
      <xsl:text>main"+delimiter+getAttr(</xsl:text>
      <xsl:value-of select='$elementSub'/>
      <xsl:text>,"gjsItem")+delimiter+gjsTree.fnMores(gCurrentCell)</xsl:text>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>"</xsl:text>
      <xsl:value-of select='$rowId'/>
      <xsl:text>main"+delimiter+getAttr(</xsl:text>
      <xsl:value-of select='$elementSub'/>
      <xsl:text>,"gjsItem")+delimiter+gjsTree.fnMores(gCurrentCell)</xsl:text>
    </xsl:otherwise>
  </xsl:choose>  

</xsl:template>


<!-- Process mru list -->
<xsl:template match='/ServerLink/mrus'>
  <xsl:call-template name='toolbarSelect'/>
  <xsl:call-template name='toolbarFilters'/>
</xsl:template>


<!-- Selection toolbar -->
<xsl:template name='toolbarSelect'>
  <div id='divToolbarSelect'>
    <table
     cellspacing='1px'
     cellpadding='1px'
     border='0px'>
      <tr>

        <td
         width='186px'>
          <select 
           style='width: 186px;'
           size='1'
           id='lstSelect' 
           name='lstSelect'
           title='Object selection specification. Can include * and ? wildcards. Accepts multiple specs separated by ;' 
           value='{/ServerLink/mrus/@currentSelection}' 
           class='input'>
            <xsl:apply-templates select="/ServerLink/filters/filter" mode='list'/>
            <xsl:apply-templates select="/ServerLink/mrus/mru" mode='list'/>
          </select>
        </td>

        <td>
          <input
           type='submit'
           class='button'
           style='height: 22px; width: 60px; padding-top: 0px;'
           id='cmdOK'
           title='Click to list objects that match the pattern in the field on the left, filtered according to the state of the buttons on the right'
           value='Refresh'
           onclick="Select.fnSelect($('#lstSelect').scombobox('val'));return false;"/>
        </td>
      </tr>
    </table>
  </div>
</xsl:template>


<!-- Filters toolbar 
Keep logic in sync with code in list^%vc780 to blank out inapplicable options
-->
<xsl:template name='toolbarFilters'>
  <div id='divToolbarFilters'>
    <table
     width='10px'
     cellspacing='1px'
     cellpadding='1px'
     border='0px'>
      <tr>

        <xsl:choose>
          <xsl:when test='/ServerLink/location/@location=""'>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnEmpty</xsl:with-param>
              <xsl:with-param name='imageDown'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='""'/>
              <xsl:with-param name='title' select='""'/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnEmpty</xsl:with-param>
              <xsl:with-param name='imageDown'>vcmObjectWhiteButtonDown.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcmObjectWhiteButtonUp.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='@empty'/>
              <xsl:with-param name='title' select='"Show objects that have no components"'/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:choose>
          <xsl:when test='/ServerLink/location/@location=""'>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnCheckedOut</xsl:with-param>
              <xsl:with-param name='imageDown'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='""'/>
              <xsl:with-param name='title' select='""'/>
            </xsl:call-template>
          </xsl:when>
          <xsl:when test='/ServerLink/location/@isLibrary!="0"'>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnCheckedOut</xsl:with-param>
              <xsl:with-param name='imageDown'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='""'/>
              <xsl:with-param name='title' select='""'/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnCheckedOut</xsl:with-param>
              <xsl:with-param name='imageDown'>vcmObjectGreenButtonDown.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcmObjectGreenButtonUp.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='@checkedOut'/>
              <xsl:with-param name='title' select='"Show checked out objects"'/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name='button'>
          <xsl:with-param name='imageId'>btnRegistered</xsl:with-param>
          <xsl:with-param name='imageDown'>vcmObjectAmberButtonDown.gif</xsl:with-param>
          <xsl:with-param name='imageUp'>vcmObjectAmberButtonUp.gif</xsl:with-param>
          <xsl:with-param name='currentState' select='@registered'/>
          <xsl:with-param name='title' select='"Show registered objects"'/>
        </xsl:call-template>

        <xsl:choose>
          <xsl:when test='/ServerLink/location/@location=""'>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnError</xsl:with-param>
              <xsl:with-param name='imageDown'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='""'/>
              <xsl:with-param name='title' select='""'/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnError</xsl:with-param>
              <xsl:with-param name='imageDown'>vcmObjectRedButtonDown.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcmObjectRedButtonUp.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='@error'/>
              <xsl:with-param name='title' select='"Show objects in error (typically indicating incomplete transfers due to network, transient or configuration problems)"'/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>

        <xsl:call-template name='button'>
          <xsl:with-param name='imageId'>btnUnregistered</xsl:with-param>
          <xsl:with-param name='imageDown'>vcm_blank.gif</xsl:with-param>
          <xsl:with-param name='imageUp'>vcm_blank.gif</xsl:with-param>
          <xsl:with-param name='currentState' select='""'/>
          <xsl:with-param name='title' select='""'/>
        </xsl:call-template>

        <xsl:call-template name='button'>
          <xsl:with-param name='imageId'>btnSuperseded</xsl:with-param>
          <xsl:with-param name='imageDown'>vcmObjectGreyButtonDown.gif</xsl:with-param>
          <xsl:with-param name='imageUp'>vcmObjectGreyButtonUp.gif</xsl:with-param>
          <xsl:with-param name='currentState' select='@superseded'/>
          <xsl:with-param name='title' select='"Show superseded versions"'/>
        </xsl:call-template>

        <xsl:choose>
          <xsl:when test='/ServerLink/location/@singleOrMultiVersion="S"'>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnAllVersions</xsl:with-param>
              <xsl:with-param name='imageDown'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcm_blank.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='""'/>
              <xsl:with-param name='title' select='""'/>
            </xsl:call-template>
          </xsl:when>
          <xsl:otherwise>
            <xsl:call-template name='button'>
              <xsl:with-param name='imageId'>btnAllVersions</xsl:with-param>
              <xsl:with-param name='imageDown'>vcmObjectAllVersionsButtonDown.gif</xsl:with-param>
              <xsl:with-param name='imageUp'>vcmObjectAllVersionsButtonUp.gif</xsl:with-param>
              <xsl:with-param name='currentState' select='@allVersions'/>
              <xsl:with-param name='title' select='"Show all versions, not just the highest"'/>
            </xsl:call-template>
          </xsl:otherwise>
        </xsl:choose>


      </tr>
    </table>
  </div>
</xsl:template>


<xsl:template match='/ServerLink/mrus/mru' mode='list'>
  <option value='{@selection}'>
    <xsl:if test="/ServerLink/mrus/@currentSelection=@selection">
      <xsl:attribute name='selected'>selected</xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@selection" />
  </option>
</xsl:template>


<xsl:template match='/ServerLink/filters/filter' mode='list'>
  <option value='{@selection}'>
    <xsl:if test="/ServerLink/mrus/@currentSelection=@selection">
      <xsl:attribute name='selected'>selected</xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@caption" />
  </option>
</xsl:template>



<xsl:template name='button'>
  <xsl:param name='imageId'/>
  <xsl:param name='imageDown'/>
  <xsl:param name='imageUp'/>
  <xsl:param name='currentState'/>
  <xsl:param name='title'/>

  <td
    align='left'
    title='{$title}'
    style='padding-top: 3px;'
    width='1'>
    <!-- Hide blank buttons -->
    <xsl:if test='($imageUp="vcm_blank.gif")'>
      <xsl:attribute name='style'>display: none;</xsl:attribute>
    </xsl:if>
    <img
      id='{$imageId}'
      onmouseover='Button.fnMouseOver(this)'
      onmouseout='Button.fnMouseOut(this)'
      onclick='Button.fnClick(this)'
      ondblclick='fnRefresh()'
      gjsImageDown='{$imageDown}'
      gjsImageUp='{$imageUp}'
      tabindex='0'
      height='25'
      width='25'>
      <xsl:choose>
        <xsl:when test='$currentState="1"'>
          <xsl:attribute name='src'><xsl:value-of select='$imageDown'/></xsl:attribute>
          <xsl:attribute name='gjsState'>1</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name='src'><xsl:value-of select='$imageUp'/></xsl:attribute>
          <xsl:attribute name='gjsState'><xsl:value-of select='$currentState'/></xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
    </img>
  </td>
</xsl:template>


<!-- Information messages -->
<xsl:template match='/ServerLink/Information'>
  <div id='divInfo'>
    <p style='color: red'>
      <img src="vcmWarning.gif"/>&nbsp;&nbsp;
      <xsl:value-of select='@message'/>
    </p>
  </div>
</xsl:template>


<!-- Swallow the mrus -->
<xsl:template match='/ServerLink/mrus/mru' />


<!-- Swallow the filters -->
<xsl:template match='/ServerLink/filters/filter' />


</xsl:stylesheet>
