<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">


<!-- Import the standard change request form, then override and extend as required -->
<xsl:import href='ChangeRequest.xsl'/>


<!-- Add one or more custom tabs to the tab-strip here -->
<xsl:template name='customTabs'>
  <gjs:tabStripTab id='tabCustom1' accesskey='C' divId='divCustom1'> <u>C</u>ustom Data </gjs:tabStripTab>
  <gjs:tabStripTab id='tabCustom2' accesskey='M' divId='divCustom2'> <u>M</u>ore Custom Data </gjs:tabStripTab>
</xsl:template>


<!-- Add a custom frame for each tab strip -->
<xsl:template name='customFrames'>

  <xsl:call-template name='customJavaScript' />

  <div id='divCustom1' class='tabPanelHidden' style='height: 350px;'>
    <gjs:frame>

    <!-- Set up form column widths -->
    <gjs:columnWidths>
      <gjs:column width='120'/>
      <gjs:column width='390'/>
    </gjs:columnWidths>

      <gjs:fields>

        <gjs:input
         id='department'
         accesskey='P'
         size='30'
         maxlength='2000'
         value='{/ChangeRequestForm/Custom/@department}'
         readonly='0'>
         <label>De<u>p</u>artment</label>
         <hint>Enter the name of the department which owns the change</hint>
        </gjs:input>


        <gjs:list1
         id='priority'
         accesskey='P'
         width='100'
         value='{/ChangeRequestForm/Custom/@priority}'
         readonly='0'>
          <label><u>P</u>riority</label>
          <hint>Select the priority applicable to this change</hint>
          <item>
            <label></label>
            <value></value>
          </item>
          <xsl:apply-templates select="/ChangeRequestForm/priorities/priority" mode='listItem'/>
        </gjs:list1>

      </gjs:fields>

    </gjs:frame>
  </div>


  <div id='divCustom2' class='tabPanelHidden' style='height: 350px;'>
    <gjs:frame>

      <!-- Set up form column widths -->
      <gjs:columnWidths>
        <gjs:column width='120'/>
        <gjs:column width='390'/>
      </gjs:columnWidths>

      <gjs:fields>

        <tr>
          <gjs:caption for='troubleTicket' accesskey='T'>
            <label><u>T</u>rouble Tickets</label>
          </gjs:caption>
          <td>
            <div class='gridTableOuter'>

              <!-- This table contains column headings for the table -->
              <table class='formLayoutTable'>
                <tr>
                  <gjs:column width='25'/>
                  <gjs:column width='100'/>
                  <gjs:column width='180'/>
                </tr>
                <tr>
                  <td></td>
                  <gjs:caption for='troubleTicket' accesskey='T'>
                    <label><u>T</u>icket #</label>
                  </gjs:caption>
                  <gjs:caption for='troubleTicketDescription' accesskey='D'>
                    <label><u>D</u>escription</label>
                  </gjs:caption>
                </tr>
              </table>

              <div class='gridTableInner' style='height: 195px; width: 330px;'>
                <table class='formLayoutTable'>
                  <tr>
                    <gjs:column width='25'/>
                    <gjs:column width='100'/>
                    <gjs:column width='180'/>
                  </tr>

                  <xsl:apply-templates select='/ChangeRequestForm/Custom/troubleTickets'/>

                </table>
              </div>
            </div>
          </td>
        </tr>
      </gjs:fields>
    </gjs:frame>
  </div>
</xsl:template>


<!-- Generate rows for each trouble ticket -->
<xsl:template match='/ChangeRequestForm/Custom/troubleTickets'>
  <!-- Set the number of display rows to control the display length of the list -->
  <xsl:variable name='numberOfDisplayRows' select='"9"'/>
  <xsl:variable name='numberOfDataRows' select='count(/ChangeRequestForm/Custom/troubleTickets/troubleTicket)'/>
  
  <!-- First row is a hidden row that is a template for new rows -->
  <xsl:call-template name='troubleTicket'>
    <xsl:with-param name='display' select='"0"'/>
    <xsl:with-param name='lastRow' select='"1"'/> <!-- sic -->
  </xsl:call-template>

  <!-- Next we render any data rows -->
  <xsl:apply-templates select='/ChangeRequestForm/Custom/troubleTickets/troubleTicket' mode='grid'>
    <xsl:with-param name='lastRow' select='"0"'/>
  </xsl:apply-templates>
  
  <!-- Now some empty rows to make sure the display window is full -->
  <xsl:call-template name='empty-rows'>
    <xsl:with-param name='n' select='number($numberOfDisplayRows)-number($numberOfDataRows)'/>
  </xsl:call-template>
  
  <!-- Finally the last row which, when filled, will generate a new row from the template -->
  <xsl:call-template name='troubleTicket'>
    <xsl:with-param name='lastRow' select='"1"'/>
  </xsl:call-template>
</xsl:template>


<!-- Generate n empty-rows -->
<xsl:template name="empty-rows">
  <xsl:param name="n"/>

  <xsl:if test="number($n) > 0">
    <xsl:call-template name='troubleTicket'>
      <xsl:with-param name='lastRow' select='"0"'/>
    </xsl:call-template>
    <!-- Call self recursively with n-1 rows -->
    <xsl:call-template name="empty-rows">
      <xsl:with-param name="n" select="number($n) - 1"/>
    </xsl:call-template>
  </xsl:if>

</xsl:template>


<!-- Generate the contents of a trouble ticket row -->
<xsl:template match='/ChangeRequestForm/Custom/troubleTickets/troubleTicket' name='troubleTicket' mode="grid">
  <xsl:param name='display' select='"1"'/>
  <xsl:param name='lastRow' select='"0"'/>

  <tr 
   title='Enter a trouble ticket number'
   gjsLastRow='{$lastRow}'>
    <xsl:if test='$display="0"'>
      <xsl:attribute name='style'>display: none;</xsl:attribute>  
    </xsl:if>

    <td>
      <img src='vcm_record.gif'
       height='16'
       width='25'
       onclick='Form.fnRowSelect(this.parentNode.parentNode,event)'
       />
    </td>

    <td>
      <input 
       type='text' 
       size='15'
       maxlength='20' 
       name='troubleTicket' 
       value='{@ticketNumber}' 
       class='input'
       onChange='Form.fnRowChanged(this.parentNode.parentNode)'/>
    </td>

    <td>
      <input 
       type='text' 
       size='30'
       maxlength='30' 
       name='troubleTicketDescription' 
       value='{@description}' 
       class='input'
       onChange='Form.fnRowChanged(this.parentNode.parentNode)'/>
    </td>

  </tr>
</xsl:template>


<!-- Generate option list of priorities -->
<xsl:template match='/ChangeRequestForm/priorities' mode='listItem'>
  <item>
    <label></label>
    <value></value>
  </item>
  <xsl:apply-templates select='priority' mode='listItem'/>
</xsl:template>


<xsl:template match='priority' mode="listItem">
  <item>
    <label><xsl:value-of select="@description" /></label>
    <value><xsl:value-of select="@code" /></value>
  </item>
</xsl:template>


<!-- Add any supporting client side javascript code here -->
<xsl:template name='customJavaScript'>
  <script>
    <![CDATA[
  
      Custom = {}

        // Collect all form data into a single string delimited by $c(2)
      Custom.fnArguments = function() {
        //
      	var delimiter = '\002'
      	var arguments
      	//
      	arguments  = frmMain.department.value
      	arguments += delimiter + frmMain.priority.value
      	//
      	// Trouble tickets are sub-delimited by $c(4) within $c(3)
      	arguments += delimiter
        if (frmMain.troubleTicket) {
      	  for (i=0; i<frmMain.troubleTicket.length; i++) {
      	  	if (frmMain.troubleTicket[i].value!='') {
      	  	  arguments += frmMain.troubleTicket[i].value + '\004'
      	  	  arguments += frmMain.troubleTicketDescription[i].value + '\004'
             arguments += '\003'
      	  	}
      	  }
        }
      	//
      	return arguments
      }

    ]]>
  </script>
</xsl:template>


</xsl:stylesheet>
