<?xml version='1.0' standalone='no'?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp '&#160;'> ]>
<xsl:stylesheet 
 version="1.0"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:gjs="http://www.georgejames.com">

  <!-- Fileset List
       ============
  -->

  <xsl:import href='gjsTree.xsl' />
  <xsl:include href='ServerLink.xsl' />
  <xsl:include href='gjsControlsTemplates.xsl' />


  <xsl:template match="/ServerLink/Rows">

    <div id='divFolderHeadingCaption'>
      <xsl:value-of select='/ServerLink/location/@location'/>
    </div>

    <div id='divMainHead'>
      <xsl:call-template name='divMainHead' />
    </div>

    <xsl:call-template name='gjs:tree' />

  </xsl:template>


  <xsl:template name='divMainHead'>

    <table class='layoutTable' width='1000'>
    	<tr>

        <xsl:call-template name='gjs:treeMoresMainHeading' />

        <td width='25'></td>

        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"100"'/> 
          <xsl:with-param name='selected' select='"ascending"'/>
          <xsl:with-param name='caption'>Fileset</xsl:with-param>         
        </xsl:call-template>

        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"150"'/> 
          <xsl:with-param name='caption'>Date Created</xsl:with-param>         
        </xsl:call-template>

        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"150"'/> 
          <xsl:with-param name='caption'>User ID</xsl:with-param>         
        </xsl:call-template>
        
        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"150"'/> 
          <xsl:with-param name='caption'>From</xsl:with-param>         
        </xsl:call-template>

        <xsl:call-template name='gjs:treeColumnHeading'>
          <xsl:with-param name='width' select='"150"'/> 
          <xsl:with-param name='caption'>To</xsl:with-param>         
        </xsl:call-template>

        <td width='*'></td>

      </tr>
    </table>

  </xsl:template>

  <xsl:template name='folderContent'>
    <xsl:param name='rowId'/>

  	<xsl:variable name='elementMain'>
  		fnElement("<xsl:value-of select='$rowId'/>main")
  	</xsl:variable>
      
    <xsl:variable name='info'>
      <xsl:value-of select='fileset/@comment' />
    </xsl:variable>

    <!-- If this is an update then use the old divReferenceHeadingId otherwise use a new unique one -->
    <xsl:variable name='divReferenceHeadingId'>
      <xsl:choose>
        <xsl:when test='../rowUpdate'>
          <xsl:value-of select='../rowUpdate/@divReferenceHeadingId' />
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select='/ServerLink/@runId' />
          <xsl:text>_mainHead</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    
    <!-- Icon for Fileset -->
    <td class='noHighlight' width='25'>
      <img
       onmousemove='fnItemMouseMove(Fileset,{$elementMain},event)'
       oncontextmenu='fnContextMenu("popFileset")'
       ondragstart='window.event.returnValue=false'
  		 onmousedown='fnItemMouseDown(Fileset,{$elementMain},event)'
  		 onmouseup='fnItemMouseUp(Fileset,{$elementMain},event)'
       src='vcm_folder.gif'
       title='{$info}'
       width='25'
       height='16'/>
    </td>

    <!-- Fileset cell -->
    <td class='treeCell'>
      <span
       nowrap='nowrap'
       id='{$rowId}main'
       tabindex='0'
  		 onmousedown='fnItemMouseDown(Fileset,this,event)'
  		 onmouseup='fnItemMouseUp(Fileset,this,event)'
       onmousemove='fnItemMouseMove(Fileset,this,event);'
       oncontextmenu='fnContextMenu("popFileset");'
       onfocus='Fileset.fnNoteValues("{/ServerLink/location/@location}","{fileset/@fileset}")'
       title='{$info}'
       gjsRowId='{$rowId}'
       gjsIconId='{$rowId}icon'
       gjsItemType='FILESET'
  		 gjsOnSpace='fnItemSpace(Fileset,event.target,event)'
  		 gjsReferenceHeadingId='{$divReferenceHeadingId}'
       gjsItem='{fileset/@fileset}'
       gjsParentId='{/ServerLink/Rows/@parentId}'
       gjsPtext='{fileset/@fileset}'>
        <xsl:value-of select='fileset/@fileset'/>
      </span>
    </td>

    <!-- header date/time -->
    <td
     gjsSort='{fileset/@creationDateTime}'
     width='150'
     nowrap='nowrap'>
      <div nowrap='nowrap'>
        <xsl:call-template name='gjs:formatDateTime'>
          <xsl:with-param name='locale' select='/ServerLink/user/@locale'/>
          <xsl:with-param name='date' select='fileset/@creationDateTime'/>
        </xsl:call-template>
      </div>
    </td>

    <!-- userid who created -->
    <td
     gjsSort='{fileset/@user}'
     width='150'
     nowrap='nowrap'>
      <div nowrap='nowrap'>
       <xsl:value-of select='fileset/@user'/>
      </div>
    </td>

    <!-- from-location of transfer that created it -->
    <td
     gjsSort='{fileset/@fromLocation}'
     width='150'
     nowrap='nowrap'>
      <div nowrap='nowrap'>
       <xsl:value-of select='fileset/@fromLocation'/>
      </div>
    </td>

    <!-- to-location of transfer that created it -->
    <td
     gjsSort='{fileset/@toLocation}'
     width='150'
     nowrap='nowrap'>
      <div nowrap='nowrap'>
       <xsl:value-of select='fileset/@toLocation'/>
      </div>
    </td>

  </xsl:template>


  <!-- Sub-folder method -->
  <xsl:template name='subFolderMethod'>
    <xsl:choose>
      <xsl:when test='/ServerLink/Rows/@expandFilesets="1"'>Fileset.fnListObjects</xsl:when>
      <xsl:otherwise>alert('Expansion of filesets is not enabled at this location')</xsl:otherwise>
    </xsl:choose>  
  </xsl:template>


  <!-- Sub-folder arguments -->
  <xsl:template name='subFolderArguments'>
    <xsl:param name='rowId'/>
    
    <xsl:text>"</xsl:text>
      <xsl:value-of select='$rowId'/>
    <xsl:text>main"</xsl:text>
    <xsl:text>+delimiter+"</xsl:text><xsl:value-of select='/ServerLink/location/@location'/><xsl:text>"</xsl:text>
    <xsl:text>+delimiter+"</xsl:text><xsl:value-of select='fileset/@fileset'/><xsl:text>"</xsl:text>
    <xsl:text>+delimiter+gjsTree.fnMores(gCurrentCell)</xsl:text>
    
    <!-- Cause the values to be noted when folder is expanded (fnNoteValues doesn't return anything) -->
    <xsl:text>+Fileset.fnNoteValues("</xsl:text><xsl:value-of select='/ServerLink/location/@location'/><xsl:text>","</xsl:text><xsl:value-of select='fileset/@fileset'/><xsl:text>")</xsl:text>

  </xsl:template>


</xsl:stylesheet>
